pub enum TerminalValues {
Range(u32, u32),
Concatenation(Vec<u32>),
}Expand description
Terminal created by numerical values.
Variants
Range(u32, u32)
A single value within a range (e.g. %x01-ff).
Concatenation(Vec<u32>)
A terminal defined by a concatenation of values (e.g. %x0f.f1.ce).
Implementations
Sourceimpl TerminalValues
impl TerminalValues
Sourcepub fn range(from: u32, to: u32) -> TerminalValues
pub fn range(from: u32, to: u32) -> TerminalValues
Create an alternation from a lower and upper bound (both inclusive).
See ABNF’s “value range alternatives”, e.g. %c##-##.
Sourcepub fn sequence(alts: &[u32]) -> TerminalValues
pub fn sequence(alts: &[u32]) -> TerminalValues
Create a terminal from a series of values.
See ABNF’s terminal notation, e.g. %c##.##.##.